% Copyright 1999-2000 by Roger S. Bivand
%
\name{interp.old.G}
\alias{interp.old.G}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Interpolation from sites to raster, Akima's old method}
\description{
 A wrapper function for \code{interp.old()} in the \code{akima} package.
}
\usage{
interp.old.G(G, x, y, z, ncp=0, extrap=FALSE, duplicate="error", dupfun=NULL
	reverse=reverse(G))
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{G}{GRASS metadata from gmeta()}
 \item{x}{Eastings of point locations}
 \item{y}{Northings of point locations}
 \item{z}{Observed point values to be interpolated}
 \item{ncp}{see \code{help(interp.old)}}
 \item{extrap}{see \code{help(interp.old)}}
 \item{duplicate}{see \code{help(interp.old)}}
 \item{dupfun}{see \code{help(interp.old)}}
 \item{reverse}{see \code{help(reverse.grassmeta)}}
}

\value{
  A vector of \code{G$Ncells} values is returned, with the results of interpolation ordered as a GRASS raster file. NAs are inserted outside the convex hull of the data points.
}
\references{\url{http://www.geog.uni-hannover.de/grass/statsgrasslist.html}, \url{http://www.baylor.edu/~grass}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Original \code{interp.old()}: Albrecht Gebhardt as detailed in the akima package documentation; adapted by Roger S. Bivand, Department of Geography, Norwegian School of Economics and Business Administration, Breiviksveien 40, N-5045 Bergen, Norway; e-mail: \email{Roger.Bivand@nhh.no.}}
\note{The functions in this package are intended to work with the GRASS geographical information system. The examples will only work if R is started from inside GRASS, choosing the location for the Pontypool PCBs data. GRASS installations differ in permissions needed to establish a new location, and system administrator privileges may be needed to create the Pontypool location. Information about the necessary metadata may be found by: \code{help(pcbs)}. The actual data may be accessed from R: \code{data(pcbs)}.}

\seealso{\code{\link{interp.new.G}}, \code{\link{interp.old}}}

\examples{
if(length(ls(pat="pcbs.o"))==0){example(pcbs)}
if(length(ls(pat="G"))==0){example(gmeta)}
inregion <- (pcbs$east >= G$w & pcbs$east <= G$e) & (pcbs$north >= G$s & pcbs$north <= G$n)
if(all(!inregion)) stop("None of the site locations are inside the current GRASS region")
if(any(!inregion)) warning("Some site locations are outside the current GRASS region")
ak1 <- interp.old.G(G, pcbs$east, pcbs$north, log(pcbs$pcbs), reverse=reverseG)
summary(ak1)
plot(G, ak1, reverse=reverseG)
points(pcbs$east, pcbs$north, pch=18)
title("Linear interpolation")
}
\keyword{GRASS, interface, spatial statistics}%-- one or more ...
