% Copyright 1999-2000 by Roger S. Bivand
%
\name{kde2d.G}
\alias{kde2d.G}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Two-Dimensional Kernel Density Estimation on a GRASS Grid}
\description{
 A version of \code{kde2d()} in the MASS package of the VR collection using the metadata of the underlying GRASS LOCATION. \code{kde2d()} is for "two-dimensional kernel density estimation with an axis-aligned bivariate normal kernel, evaluated on a square grid."
}
\usage{
kde2d.G(x, y, h, G, reverse=reverse(G))
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{x}{x coordinate of data}
 \item{y}{y coordinate of data}
 \item{h}{vector of bandwidths for x and y directions.
             Defaults to normal reference bandwidth.}
 \item{G}{GRASS metadata from \code{gmeta()}}
 \item{reverse}{see \code{help(reverse.grassmeta)}}
}
\value{
  A vector of \code{G$Ncells} values is returned, with the results of interpolation ordered as a GRASS raster file.
}
\references{\url{http://www.geog.uni-hannover.de/grass/statsgrasslist.html}, \url{http://www.baylor.edu/~grass}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Original \code{kde2d()}: Brian D. Ripley and Bill Venables as detailed in the MASS package documentation; adapted by Roger S. Bivand, Department of Geography, Norwegian School of Economics and Business Administration, Breiviksveien 40, N-5045 Bergen, Norway; e-mail: \email{Roger.Bivand@nhh.no.}}
\note{The functions in this package are intended to work with the GRASS geographical information system. The examples will only work if R is started from inside GRASS, choosing the location for the Pontypool PCBs data. GRASS installations differ in permissions needed to establish a new location, and system administrator privileges may be needed to create the Pontypool location. Information about the necessary metadata may be found by: \code{help(pcbs)}. The actual data may be accessed from R: \code{data(pcbs)}.}

\seealso{\code{\link{kde2d}}}

\examples{
if(length(ls(pat="pcbs.o"))==0){example(pcbs)}
if(length(ls(pat="G"))==0){example(gmeta)}
inregion <- (pcbs$east >= G$w & pcbs$east <= G$e) & (pcbs$north >= G$s & pcbs$north <= G$n)
if(all(!inregion)) stop("None of the site locations are inside the current GRASS region")
if(any(!inregion)) warning("Some site locations are outside the current GRASS region")
plot(G, kde2d.G(pcbs$east, pcbs$north, h=c(500,500), G=G, reverse=reverseG),
xlab="Bandwidth (500,500)", reverse=reverseG)
points(pcbs$east, pcbs$north, pch=18)
rug(pcbs$east, side=1, ticksize=0.02)
rug(pcbs$north, side=2, ticksize=0.02)
title("Kernel estimates of density of soil sample placing")
}
\keyword{GRASS, interface, spatial statistics}%-- one or more ...
