% Copyright 1999-2000 by Roger S. Bivand
%
\name{semat.G}
\alias{semat.G}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Evaluate Kriging Standard Error of Prediction over a GRASS Grid}
\description{
 A wrapper for \code{semat()} from the \code{spatial} package in the VR collection, using the metadata of the underlying GRASS LOCATION.
}
\usage{
semat.G(obj, G, se, east=east(G), north=north(G))
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{obj}{object returned by \code{surf.gls}}
 \item{G}{GRASS metadata from \code{gmeta()}}
 \item{se}{standard error at distance zero as a multiple of the supplied covariance. Otherwise estimated, and it assumed that a correlation function was supplied.}
 \item{east}{see \code{help(east.grassmeta)}}
 \item{north}{see \code{help(north.grassmeta)}}
}
\value{
  A vector of \code{G$Ncells} values is returned, with the results of interpolation ordered as a GRASS raster file.
}
\references{\url{http://www.geog.uni-hannover.de/grass/statsgrasslist.html}, \url{http://www.baylor.edu/~grass}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Original \code{semat()}: Brian D. Ripley and Bill Venables as detailed in the spatial package documentation; adapted by Roger S. Bivand, Department of Geography, Norwegian School of Economics and Business Administration, Breiviksveien 40, N-5045 Bergen, Norway; e-mail: \email{Roger.Bivand@nhh.no.}}
\note{The functions in this package are intended to work with the GRASS geographical information system. The examples will only work if R is started from inside GRASS, choosing the location for the Pontypool PCBs data. GRASS installations differ in permissions needed to establish a new location, and system administrator privileges may be needed to create the Pontypool location. Information about the necessary metadata may be found by: \code{help(pcbs)}. The actual data may be accessed from R: \code{data(pcbs)}.}

\seealso{\code{\link{semat}}}

\examples{
if(length(ls(pat="pcbs.o"))==0){example(pcbs)}
G <- gmeta()
eastG <- east(G)
northG <- north(G)
reverseG <- reverse(G)
oldpar <- par(mfrow=c(2,2))
plot(G)
points(pcbs$east, pcbs$north, pch=codes(pcbs.o), cex=0.7)
legend(x=c(67470, 68500), y=c(74500, 75300), pch=c(1:5), cex=0.7,
legend=levels(pcbs.o))
title("PCBs contamination levels")
inregion <- (pcbs$east >= G$w & pcbs$east <= G$e) & (pcbs$north >= G$s & pcbs$north <= G$n)
if(all(!inregion)) stop("None of the site locations are inside the current GRASS region")
if(any(!inregion)) warning("Some site locations are outside the current GRASS region")
lpcbs <- data.frame(x=pcbs$east, y=pcbs$north, z=log(pcbs$pcbs))
require(spatial)
tr3.lpcbs <- surf.ls(3, lpcbs)
plot(G, trmat.G(tr3.lpcbs, G, east=eastG, north=northG), reverse=reverseG)
points(pcbs$east, pcbs$north, pch=18)
title("Cubic trend surface")
kr.pcb <- surf.gls(3, expcov, lpcbs, d=1200, se=1.4)
plot(G, prmat.G(kr.pcb, G, east=eastG, north=northG), reverse=reverseG)
points(pcbs$east, pcbs$north, pch=18)
title("Kriged surface")
plot(G, semat.G(kr.pcb, G, east=eastG, north=northG), reverse=reverseG)
points(pcbs$east, pcbs$north, pch=18)
title("Standard errors of kriged surface")
par(oldpar)
}
\keyword{GRASS, interface, spatial statistics}%-- one or more ...
