% Copyright 1999-2000 by Roger S. Bivand
%
\name{sites.put}
\alias{sites.put}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Export GRASS sites file}
\description{
 \code{sites.put} moves a single numeric or character vector site to GRASS, using the metadata from \code{gmeta()}.
}
\usage{
sites.put(G, lname="", east, north, var, debug=FALSE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{G}{GRASS metadata from \code{gmeta()}}
 \item{lname}{Name for new GRASS sites file}
 \item{east}{Eastings of points}
 \item{north}{Northings of points}
 \item{var}{numeric or character vector of attribute values at these points for export}
 \item{debug}{if TRUE, the temporary ASCII file used for transfer is not deleted on exit from the function}
}
\value{
  none
}
\references{\url{http://www.geog.uni-hannover.de/grass/statsgrasslist.html}, \url{http://www.baylor.edu/~grass}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Roger S. Bivand, Department of Geography, Norwegian School of Economics and Business Administration, Breiviksveien 40, N-5045 Bergen, Norway; e-mail: \email{Roger.Bivand@nhh.no.}}
\note{The functions in this package are intended to work with the GRASS geographical information system. The examples will only work if R is started from inside GRASS, choosing the location for the Pontypool PCBs data. GRASS installations differ in permissions needed to establish a new location, and system administrator privileges may be needed to create the Pontypool location. Information about the necessary metadata may be found by: \code{help(pcbs)}. The actual data may be accessed from R: \code{data(pcbs)}.}

\seealso{\code{\link{sites.get}}}

\examples{
if(length(ls(pat="pcbs.o"))==0){example(pcbs)}
G <- gmeta()
nameQ <- c("ex.pcbs.in", "ex.pcbslog.in", "ex.pcbscat.in")
namesG <- list.GRASS("sites")
if(any(match(nameQ, namesG, nomatch=0) > 0)){
	for (i in 1:3) if(match(nameQ[i], namesG, nomatch=0) > 0)
		system(paste("g.remove sites=", nameQ[i], sep=""))
}
sites.put(G, lname=nameQ[1], east=pcbs$east, north=pcbs$north, var=pcbs$pcbs)
sites.put(G, lname=nameQ[2], east=pcbs$east, north=pcbs$north, var=log(pcbs$pcbs))
sites.put(G, lname=nameQ[3], east=pcbs$east, north=pcbs$north, var=pcbs.o)
for (i in 1:3) system(paste("s.info sites=", nameQ[i], sep=""))
}
\keyword{GRASS, interface, spatial statistics}%-- one or more ...
